<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Product Attachments Graph Ql for Magento 2 (System)
 */

namespace Amasty\ProductAttachmentGraphQl\Test\GraphQl;

use Magento\Store\Model\StoreManagerInterface;
use Magento\TestFramework\TestCase\GraphQlAbstract;
use Magento\TestFramework\Helper\Bootstrap;
use Amasty\ProductAttachment\Api\FileRepositoryInterface;

class GetAmFilesTest extends GraphQlAbstract
{
    public const MAIN_QUERY_KEY = 'getAmFiles';

    /**
     * @var FileRepositoryInterface
     */
    private $fileRepository;

    protected function setUp(): void
    {
        parent::setUp();

        $objectManager = Bootstrap::getObjectManager();
        $this->fileRepository = $objectManager->get(FileRepositoryInterface::class);
    }

    /**
     * @group amasty_attachment
     *
     * @magentoApiDataFixture Amasty_ProductAttachmentGraphQl::Test/GraphQl/_files/am_create_attachment.php
     */
    public function testGetAmFiles()
    {
        $objectManager = Bootstrap::getObjectManager();

        $file = $this->fileRepository->getByHash('prod_attachment_url');
        $fileId = $file->getFileId();

        $storeManager = $objectManager->get(StoreManagerInterface::class);
        $storeBaseUrl = $storeManager->getStore()->getBaseUrl('link');

        $fileUrlStaticPart = "/amfile/file/download/file/";
        $fileUrl = rtrim($storeBaseUrl, '/') . $fileUrlStaticPart . $fileId . '/';

        $iconUrlStaticPart = "/media/amasty/amfile/icon/Image.png";
        $iconUrl = rtrim($storeBaseUrl, '/') . $iconUrlStaticPart;

        $assertArray = [
            [
            "file_id" => $fileId,
            "filename" => "Product Attachment Name",
            "icon_url" => "$iconUrl",
            "label" => "Product Attachment Label",
            "mime_type" => "image/jpeg",
            "size" => 10440,
            "url" => "$fileUrl"
            ]
        ];

        $query = $this->getQuery($fileId);
        $response = $this->graphQlQuery($query);

        $this->assertArrayHasKey(self::MAIN_QUERY_KEY, $response);
        $this->assertResponseFields($response[self::MAIN_QUERY_KEY], $assertArray);
    }

    /**
     * @param int $fileId
     *
     * @return string
     */
    private function getQuery(int $fileId): string
    {
        return <<<QUERY
query{
   getAmFiles (ids:[$fileId])
   {
     file_id
     filename
     icon_url
     label
     mime_type
     size
     url
  }
}
QUERY;
    }
}
