<?php

declare(strict_types=1);

/**
 * @author Amasty Team
 * @copyright Copyright (c) Amasty (https://www.amasty.com)
 * @package Product Attachments Graph Ql for Magento 2 (System)
 */

namespace Amasty\ProductAttachmentGraphQl\Test\GraphQl;

use Magento\TestFramework\TestCase\GraphQlAbstract;

class GetAmProdAttachSettingsTest extends GraphQlAbstract
{
    public const MAIN_QUERY_KEY = 'getAmProductAttachmentSettings';

    /**
     * @group amasty_attachment
     *
     * @magentoConfigFixture default_store amfile/order_view/label Product Attachments Label
     * @magentoConfigFixture default_store amfile/order_view/include_attachments_filter 1
     * @magentoConfigFixture default_store amfile/product_tab/block_sort_order 77
     * @magentoConfigFixture default_store amfile/product_tab/block_label Product Attachments Label
     * @magentoConfigFixture default_store amfile/product_tab/block_fileicon 0
     * @magentoConfigFixture default_store amfile/order_view/filesize 0
     * @magentoConfigFixture default_store amfile/general/url_type 1
     */
    public function testGetAmProdAttachSettings()
    {
        $expectedResponse = [
            "addCategoryFilesToProducts" => true,
            "displayInOrderFiles" => true,
            "isEnabled" => true,
            "isShowInOrderView" => true,
            "isShowProductAttachmentTab" => true,
            "orderViewAttachmentsTitle" => "Product Attachments Label",
            "orderViewAttachmentsType" => "1",
            "productAttachmentTabPosition" => "77",
            "productAttachmentTabTitle" => "Product Attachments Label",
            "showFileIcon" => false,
            "showFileIconOrder" => true,
            "showFileSize" => true,
            "showFileSizeOrder" => false,
            "urlCreationType" => "1"
        ];

        $query = $this->getQuery();
        $response = $this->graphQlQuery($query);

        $this->assertArrayHasKey(self::MAIN_QUERY_KEY, $response);
        $this->assertResponseFields($response[self::MAIN_QUERY_KEY], $expectedResponse);
    }

    /**
     * @return string
     */
    private function getQuery(): string
    {
        return <<<QUERY
query{
   getAmProductAttachmentSettings{
     addCategoryFilesToProducts
     displayInOrderFiles
     isEnabled
     isShowInOrderView
     isShowProductAttachmentTab
     orderViewAttachmentsTitle
     orderViewAttachmentsType
     productAttachmentTabPosition
     productAttachmentTabTitle
     showFileIcon
     showFileIconOrder
     showFileSize
     showFileSizeOrder
     urlCreationType
  }
}
QUERY;
    }
}
